@@ -63,6 +63,10 @@ in any command that also has a `--detach` option.
 
     Optional directory to change to after detaching.
 
+.. cmdoption:: --executable
+
+    Executable to use for the detached process.
+
 """
 from __future__ import absolute_import, print_function, unicode_literals
 
@@ -500,6 +504,10 @@ class Command(object):
     def parse_preload_options(self, args):
         return self.preparse_options(args, self.preload_options)
 
+    def add_append_opt(self, acc, opt, value):
+        acc.setdefault(opt.dest, opt.default or [])
+        acc[opt.dest].append(value)
+
     def preparse_options(self, args, options):
         acc = {}
         opts = {}
@@ -515,13 +523,19 @@ class Command(object):
                     key, value = arg.split('=', 1)
                     opt = opts.get(key)
                     if opt:
-                        acc[opt.dest] = value
+                        if opt.action == 'append':
+                            self.add_append_opt(acc, opt, value)
+                        else:
+                            acc[opt.dest] = value
                 else:
                     opt = opts.get(arg)
                     if opt and opt.takes_value():
                         # optparse also supports ['--opt', 'value']
                         # (Issue #1668)
-                        acc[opt.dest] = args[index + 1]
+                        if opt.action == 'append':
+                            self.add_append_opt(acc, opt, args[index + 1])
+                        else:
+                            acc[opt.dest] = args[index + 1]
                         index += 1
                     elif opt and opt.action == 'store_true':
                         acc[opt.dest] = True
@@ -650,4 +664,5 @@ def daemon_options(default_pidfile=None, default_logfile=None):
         Option('--uid', default=None),
         Option('--gid', default=None),
         Option('--umask', default=None),
+        Option('--executable', default=None),
     )
