@@ -7,18 +7,21 @@
 
 """
 from __future__ import absolute_import
-from __future__ import with_statement
+
+from kombu.utils.encoding import ensure_bytes
 
 from .utils import crypto, reraise_errors
 
+__all__ = ['PrivateKey']
+
 
 class PrivateKey(object):
 
     def __init__(self, key):
-        with reraise_errors('Invalid private key: %r'):
+        with reraise_errors('Invalid private key: {0!r}'):
             self._key = crypto.load_privatekey(crypto.FILETYPE_PEM, key)
 
     def sign(self, data, digest):
         """sign string containing data."""
-        with reraise_errors('Unable to sign data: %r'):
-            return crypto.sign(self._key, data, digest)
+        with reraise_errors('Unable to sign data: {0!r}'):
+            return crypto.sign(self._key, ensure_bytes(data), digest)
