@@ -1,20 +1,14 @@
 from __future__ import absolute_import
-from __future__ import with_statement
+
+import warnings
 
 from functools import wraps
 
 from kombu.pidbox import Mailbox
 
-from celery.app import app_or_default
 from celery.app import control
-from celery.task import task
 from celery.utils import uuid
-from celery.tests.utils import Case
-
-
-@task()
-def mytask():
-    pass
+from celery.tests.case import AppCase
 
 
 class MockMailbox(Mailbox):
@@ -46,17 +40,31 @@ def with_mock_broadcast(fun):
     return _resets
 
 
-class test_inspect(Case):
+class test_flatten_reply(AppCase):
 
-    def setUp(self):
-        app = self.app = app_or_default()
-        self.c = Control(app=app)
-        self.prev, app.control = app.control, self.c
+    def test_flatten_reply(self):
+        reply = [
+            {'foo@example.com': {'hello': 10}},
+            {'foo@example.com': {'hello': 20}},
+            {'bar@example.com': {'hello': 30}}
+        ]
+        with warnings.catch_warnings(record=True) as w:
+            nodes = control.flatten_reply(reply)
+            self.assertIn(
+                'multiple replies',
+                str(w[-1].message),
+            )
+            self.assertIn('foo@example.com', nodes)
+            self.assertIn('bar@example.com', nodes)
+
+
+class test_inspect(AppCase):
+
+    def setup(self):
+        self.c = Control(app=self.app)
+        self.prev, self.app.control = self.app.control, self.c
         self.i = self.c.inspect()
 
-    def tearDown(self):
-        self.app.control = self.prev
-
     def test_prepare_reply(self):
         self.assertDictEqual(self.i._prepare([{'w1': {'ok': 1}},
                                               {'w2': {'ok': 1}}]),
@@ -71,6 +79,36 @@ class test_inspect(Case):
         self.i.active()
         self.assertIn('dump_active', MockMailbox.sent)
 
+    @with_mock_broadcast
+    def test_clock(self):
+        self.i.clock()
+        self.assertIn('clock', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_conf(self):
+        self.i.conf()
+        self.assertIn('dump_conf', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_hello(self):
+        self.i.hello('george@vandelay.com')
+        self.assertIn('hello', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_memsample(self):
+        self.i.memsample()
+        self.assertIn('memsample', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_memdump(self):
+        self.i.memdump()
+        self.assertIn('memdump', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_objgraph(self):
+        self.i.objgraph()
+        self.assertIn('objgraph', MockMailbox.sent)
+
     @with_mock_broadcast
     def test_scheduled(self):
         self.i.scheduled()
@@ -112,15 +150,16 @@ class test_inspect(Case):
         self.assertIn('report', MockMailbox.sent)
 
 
-class test_Broadcast(Case):
+class test_Broadcast(AppCase):
 
-    def setUp(self):
-        self.app = app_or_default()
+    def setup(self):
         self.control = Control(app=self.app)
         self.app.control = self.control
 
-    def tearDown(self):
-        del(self.app.control)
+        @self.app.task(shared=False)
+        def mytask():
+            pass
+        self.mytask = mytask
 
     def test_purge(self):
         self.control.purge()
@@ -145,12 +184,12 @@ class test_Broadcast(Case):
 
     @with_mock_broadcast
     def test_rate_limit(self):
-        self.control.rate_limit(mytask.name, '100/m')
+        self.control.rate_limit(self.mytask.name, '100/m')
         self.assertIn('rate_limit', MockMailbox.sent)
 
     @with_mock_broadcast
     def test_time_limit(self):
-        self.control.time_limit(mytask.name, soft=10, hard=20)
+        self.control.time_limit(self.mytask.name, soft=10, hard=20)
         self.assertIn('time_limit', MockMailbox.sent)
 
     @with_mock_broadcast
@@ -183,6 +222,21 @@ class test_Broadcast(Case):
         self.control.ping()
         self.assertIn('ping', MockMailbox.sent)
 
+    @with_mock_broadcast
+    def test_election(self):
+        self.control.election('some_id', 'topic', 'action')
+        self.assertIn('election', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_pool_grow(self):
+        self.control.pool_grow(2)
+        self.assertIn('pool_grow', MockMailbox.sent)
+
+    @with_mock_broadcast
+    def test_pool_shrink(self):
+        self.control.pool_shrink(2)
+        self.assertIn('pool_shrink', MockMailbox.sent)
+
     @with_mock_broadcast
     def test_revoke_from_result(self):
         self.app.AsyncResult('foozbazzbar').revoke()
@@ -191,7 +245,7 @@ class test_Broadcast(Case):
     @with_mock_broadcast
     def test_revoke_from_resultset(self):
         r = self.app.GroupResult(uuid(),
-                                 map(self.app.AsyncResult,
-                                     [uuid() for i in range(10)]))
+                                 [self.app.AsyncResult(x)
+                                  for x in [uuid() for i in range(10)]])
         r.revoke()
         self.assertIn('revoke', MockMailbox.sent)
