@@ -38,6 +38,7 @@ from celery.exceptions import InvalidTaskError
 from celery.five import items, values
 from celery.utils.functional import noop
 from celery.utils.log import get_logger
+from celery.utils.objects import Bunch
 from celery.utils.text import truncate
 from celery.utils.timeutils import humanize_seconds, rate
 
@@ -270,7 +271,7 @@ class Consumer(object):
             self.on_task_request(request)
 
     def start(self):
-        blueprint, loop = self.blueprint, self.loop
+        blueprint = self.blueprint
         while blueprint.state != CLOSE:
             self.restart_count += 1
             maybe_shutdown()
@@ -672,6 +673,11 @@ class Gossip(bootsteps.ConsumerStep):
         self.Receiver = c.app.events.Receiver
         self.hostname = c.hostname
         self.full_hostname = '.'.join([self.hostname, str(c.pid)])
+        self.on = Bunch(
+            node_join=set(),
+            node_leave=set(),
+            node_lost=set(),
+        )
 
         self.timer = c.timer
         if self.enabled:
@@ -758,12 +764,23 @@ class Gossip(bootsteps.ConsumerStep):
 
     def on_node_join(self, worker):
         debug('%s joined the party', worker.hostname)
+        self._call_handlers(self.on.node_join, worker)
 
     def on_node_leave(self, worker):
         debug('%s left', worker.hostname)
+        self._call_handlers(self.on.node_leave, worker)
 
     def on_node_lost(self, worker):
         info('missed heartbeat from %s', worker.hostname)
+        self._call_handlers(self.on.node_lost, worker)
+
+    def _call_handlers(self, handlers, *args, **kwargs):
+        for handler in handlers:
+            try:
+                handler(*args, **kwargs)
+            except Exception as exc:
+                error('Ignored error from handler %r: %r',
+                      handler, exc, exc_info=1)
 
     def register_timer(self):
         if self._tref is not None:
@@ -807,7 +824,7 @@ class Gossip(bootsteps.ConsumerStep):
                     message.payload['hostname'])
         if hostname != self.hostname:
             type, event = prepare(message.payload)
-            obj, subject = self.update_state(event)
+            self.update_state(event)
         else:
             self.clock.forward()
 
