@@ -5,8 +5,8 @@ try:
 except ImportError:
     import sys
     sys.stderr.write(
-        "Error: Can't find the file 'settings.py' in the directory \
-         containing %r." % __file__)
+        "Error: Can't find the file 'settings.py' in the directory "
+        "containing {0!r}.".format(__file__))
     sys.exit(1)
 
 if __name__ == '__main__':
