@@ -3,4 +3,4 @@ from celery import task
 
 @task()
 def hello_world(to='world'):
-    return 'Hello %s' % to
+    return 'Hello {0}'.format(to)
