@@ -133,6 +133,8 @@ INSTALLED_APPS = (
     'django.contrib.sites',
     'django.contrib.messages',
     'django.contrib.staticfiles',
+    'django.contrib.admin',
+    'kombu.transport.django',
     'demoapp',
     # Uncomment the next line to enable the admin:
     # 'django.contrib.admin',
