@@ -2,7 +2,8 @@ import os
 import sys
 sys.path.insert(0, os.getcwd())
 
-CELERYD_POOL = 'gevent'
+# ## Note: Start worker with -P gevent,
+# do not use the CELERYD_POOL option.
 
 BROKER_URL = 'amqp://guest:guest@localhost:5672//'
 CELERY_DISABLE_RATE_LIMITS = True
